Learn R Programming

Johnson (version 1.0)

RE.Johnson: Johnson transformation

Description

Johnson transform to normality using the Z family of distributions. Performs the Johnson Transformation based on the method of the percentiles. Returns the the transformed variable, the function used and de p-value of the transformation.

Usage

RE.Johnson(x)

Arguments

x
x vector of observations

Value

  • The objects returned consists of the following items: function type of function used in trnaformation (SB,SL or SU) p-value the resulting p-value od the transformation transformed the data vector of transformed variable

References

Chou, Youn Min; Polansky, A. M. M. R. L. (1998), "Transforming non normal data to normality in statistical process control", Journal of Quality Technology 30, 2, April. Johnson, N. L. (1949), "Systems of Frequency Curves Generated by Methods of Translation". URL: http://www.jstor.org/stable/2332539 Slifker, J. F. & Shapiro, S. S. (1980), "The johnson system: selection and parameter estimation", Technometrics 22(2).

Examples

Run this code
# transforming to normality a random sample with beta distribution
x<-rbeta(30,2,3)
y<-RE.Johnson(x);print(y)

# working with the transformed variable
x<-runif(100)
y<-RE.Johnson(x)$transformed;print(y)

# working with the p-values
x<-runif(50)
y<-RE.Johnson(x)$p;print(y)

Run the code above in your browser using DataLab